==================
SSL Expiry Monitor
==================


.. image:: https://img.shields.io/pypi/v/ssl_expiry_monitor.svg
        :target: https://pypi.python.org/pypi/ssl_expiry_monitor

Function (Script) to measure and report on hosts SSL expiry.

Bundles with an AWS Lambda Function to publish metrics to AWS CloudWatch.
This allows to create alarms based on the certificate expiry date and take action.
